@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007 - 2016 Joseph Gaeddert
+ * Copyright (c) 2007 - 2017 Joseph Gaeddert
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -570,6 +570,7 @@ unsigned int fec_rs_get_enc_msg_len(unsigned int _dec_msg_len,
 
 
 fec fec_rs_create(fec_scheme _fs);
+void fec_rs_destroy(fec _q);
 void fec_rs_init_p8(fec _q);
 void fec_rs_setlength(fec _q,
                       unsigned int _dec_msg_len);
@@ -802,12 +803,12 @@ float estimate_req_filter_len_Herrmann(float _df,
 #define LIQUID_FIRFARROW_DEFINE_INTERNAL_API(FIRFARROW,TO,TC,TI)  \
 void FIRFARROW(_genpoly)(FIRFARROW() _q);
 
-LIQUID_FIRFARROW_DEFINE_INTERNAL_API(FIRFARROW_MANGLE_RRRF,
+LIQUID_FIRFARROW_DEFINE_INTERNAL_API(LIQUID_FIRFARROW_MANGLE_RRRF,
                                      float,
                                      float,
                                      float)
 
-LIQUID_FIRFARROW_DEFINE_INTERNAL_API(FIRFARROW_MANGLE_CRCF,
+LIQUID_FIRFARROW_DEFINE_INTERNAL_API(LIQUID_FIRFARROW_MANGLE_CRCF,
                                      liquid_float_complex,
                                      float,
                                      liquid_float_complex)
@@ -817,24 +818,13 @@ LIQUID_FIRFARROW_DEFINE_INTERNAL_API(FIRFARROW_MANGLE_CRCF,
 // 
 // iirfiltsos : infinite impulse respone filter (second-order sections)
 //
-#define IIRFILTSOS_MANGLE_RRRF(name)  LIQUID_CONCAT(iirfiltsos_rrrf,name)
-#define IIRFILTSOS_MANGLE_CRCF(name)  LIQUID_CONCAT(iirfiltsos_crcf,name)
-#define IIRFILTSOS_MANGLE_CCCF(name)  LIQUID_CONCAT(iirfiltsos_cccf,name)
+#define LIQUID_IIRFILTSOS_MANGLE_RRRF(name)  LIQUID_CONCAT(iirfiltsos_rrrf,name)
+#define LIQUID_IIRFILTSOS_MANGLE_CRCF(name)  LIQUID_CONCAT(iirfiltsos_crcf,name)
+#define LIQUID_IIRFILTSOS_MANGLE_CCCF(name)  LIQUID_CONCAT(iirfiltsos_cccf,name)
 
 #define LIQUID_IIRFILTSOS_DEFINE_INTERNAL_API(IIRFILTSOS,TO,TC,TI)  \
 typedef struct IIRFILTSOS(_s) * IIRFILTSOS();                   \
                                                                 \
-/* filter structure */                                          \
-struct IIRFILTSOS(_s) {                                         \
-    TC b[3];    /* feed-forward coefficients                */  \
-    TC a[3];    /* feed-back coefficients                   */  \
-                                                                \
-    /* internal buffering                                   */  \
-    TI x[3];    /* Direct form I  buffer (input)            */  \
-    TO y[3];    /* Direct form I  buffer (output)           */  \
-    TO v[3];    /* Direct form II buffer                    */  \
-};                                                              \
-                                                                \
 /* create 2nd-order infinite impulse reponse filter         */  \
 /*  _b      : feed-forward coefficients [size: _3 x 1]      */  \
 /*  _a      : feed-back coefficients    [size: _3 x 1]      */  \
@@ -888,17 +878,17 @@ void IIRFILTSOS(_execute_df2)(IIRFILTSOS() _q,                  \
 float IIRFILTSOS(_groupdelay)(IIRFILTSOS() _q,                  \
                               float        _fc);                \
 
-LIQUID_IIRFILTSOS_DEFINE_INTERNAL_API(IIRFILTSOS_MANGLE_RRRF,
+LIQUID_IIRFILTSOS_DEFINE_INTERNAL_API(LIQUID_IIRFILTSOS_MANGLE_RRRF,
                                       float,
                                       float,
                                       float)
 
-LIQUID_IIRFILTSOS_DEFINE_INTERNAL_API(IIRFILTSOS_MANGLE_CRCF,
+LIQUID_IIRFILTSOS_DEFINE_INTERNAL_API(LIQUID_IIRFILTSOS_MANGLE_CRCF,
                                       liquid_float_complex,
                                       float,
                                       liquid_float_complex)
 
-LIQUID_IIRFILTSOS_DEFINE_INTERNAL_API(IIRFILTSOS_MANGLE_CCCF,
+LIQUID_IIRFILTSOS_DEFINE_INTERNAL_API(LIQUID_IIRFILTSOS_MANGLE_CCCF,
                                       liquid_float_complex,
                                       liquid_float_complex,
                                       liquid_float_complex)
@@ -988,28 +978,6 @@ void liquid_firdes_farcsech_freqresponse(unsigned int _k,
                                          float        _beta,
                                          float *      _H);
 
-
-
-// initialize the frequency grid on the disjoint bounded set
-void firdespm_init_grid(firdespm _q);
-
-// compute interpolating polynomial
-void firdespm_compute_interp(firdespm _q);
-
-// compute error signal from actual response (interpolator
-// output), desired response, and weights
-void firdespm_compute_error(firdespm _q);
-
-// search error curve for _r+1 extremal indices
-void firdespm_iext_search(firdespm _q);
-
-// evaluates result to determine if Remez exchange algorithm
-// has converged
-int firdespm_is_search_complete(firdespm _q);
-
-// compute filter taps (coefficients) from result
-void firdespm_compute_taps(firdespm _q, float * _h);
-
 // iirdes : infinite impulse response filter design
 
 // Sorts array _z of complex numbers into complex conjugate pairs to
@@ -1219,11 +1187,11 @@ T    MATRIX(_det2x2)(T * _x,                                    \
                      unsigned int _cx);
 
 
-LIQUID_MATRIX_DEFINE_INTERNAL_API(MATRIX_MANGLE_FLOAT,   float)
-LIQUID_MATRIX_DEFINE_INTERNAL_API(MATRIX_MANGLE_DOUBLE,  double)
+LIQUID_MATRIX_DEFINE_INTERNAL_API(LIQUID_MATRIX_MANGLE_FLOAT,   float)
+LIQUID_MATRIX_DEFINE_INTERNAL_API(LIQUID_MATRIX_MANGLE_DOUBLE,  double)
 
-LIQUID_MATRIX_DEFINE_INTERNAL_API(MATRIX_MANGLE_CFLOAT,  liquid_float_complex)
-LIQUID_MATRIX_DEFINE_INTERNAL_API(MATRIX_MANGLE_CDOUBLE, liquid_double_complex)
+LIQUID_MATRIX_DEFINE_INTERNAL_API(LIQUID_MATRIX_MANGLE_CFLOAT,  liquid_float_complex)
+LIQUID_MATRIX_DEFINE_INTERNAL_API(LIQUID_MATRIX_MANGLE_CDOUBLE, liquid_double_complex)
 
 
 // sparse 'alist' matrix type (similar to MacKay, Davey Lafferty convention)
@@ -1235,9 +1203,9 @@ LIQUID_MATRIX_DEFINE_INTERNAL_API(MATRIX_MANGLE_CDOUBLE, liquid_double_complex)
 void SMATRIX(_reset_max_mlist)(SMATRIX() _q);                   \
 void SMATRIX(_reset_max_nlist)(SMATRIX() _q);                   \
 
-LIQUID_SMATRIX_DEFINE_INTERNAL_API(SMATRIX_MANGLE_BOOL,  unsigned char)
-LIQUID_SMATRIX_DEFINE_INTERNAL_API(SMATRIX_MANGLE_FLOAT, float)
-LIQUID_SMATRIX_DEFINE_INTERNAL_API(SMATRIX_MANGLE_INT,   short int)
+LIQUID_SMATRIX_DEFINE_INTERNAL_API(LIQUID_SMATRIX_MANGLE_BOOL,  unsigned char)
+LIQUID_SMATRIX_DEFINE_INTERNAL_API(LIQUID_SMATRIX_MANGLE_FLOAT, float)
+LIQUID_SMATRIX_DEFINE_INTERNAL_API(LIQUID_SMATRIX_MANGLE_INT,   short int)
 
 // search for index placement in list
 unsigned short int smatrix_indexsearch(unsigned short int * _list,
@@ -1559,7 +1527,7 @@ void NCO(_compute_sincos_vco)(NCO() _q);                        \
 void NCO(_pll_reset)(NCO() _q);                                 \
 
 // Define nco internal APIs
-LIQUID_NCO_DEFINE_INTERNAL_API(NCO_MANGLE_FLOAT,
+LIQUID_NCO_DEFINE_INTERNAL_API(LIQUID_NCO_MANGLE_FLOAT,
                                float,
                                float complex)
 
